@@ -38,18 +38,20 @@ use SNMP::Info;
 use SNMP::Info::Bridge;
 use SNMP::Info::Entity;
 use SNMP::Info::PowerEthernet;
+use SNMP::Info::LLDP;
 
 @SNMP::Info::Layer2::ISA
-    = qw/SNMP::Info SNMP::Info::Bridge SNMP::Info::Entity SNMP::Info::PowerEthernet Exporter/;
+    = qw/SNMP::Info SNMP::Info::Bridge SNMP::Info::Entity SNMP::Info::PowerEthernet SNMP::Info::LLDP Exporter/;
 @SNMP::Info::Layer2::EXPORT_OK = qw//;
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %PORTSTAT %MUNGE/;
 
-$VERSION = '2.06';
+$VERSION = '3.31';
 
 %MIBS = (
     %SNMP::Info::MIBS,         %SNMP::Info::Bridge::MIBS,
     %SNMP::Info::Entity::MIBS, %SNMP::Info::PowerEthernet::MIBS,
+    %SNMP::Info::LLDP::MIBS,
 );
 
 %GLOBALS = (
@@ -57,6 +59,7 @@ $VERSION = '2.06';
     %SNMP::Info::Bridge::GLOBALS,
     %SNMP::Info::Entity::GLOBALS,
     %SNMP::Info::PowerEthernet::GLOBALS,
+    %SNMP::Info::LLDP::GLOBALS,
     'serial1' =>
         '.1.3.6.1.4.1.9.3.6.3.0',    # OLD-CISCO-CHASSIS-MIB::chassisId.0
 );
@@ -64,6 +67,7 @@ $VERSION = '2.06';
 %FUNCS = (
     %SNMP::Info::FUNCS,         %SNMP::Info::Bridge::FUNCS,
     %SNMP::Info::Entity::FUNCS, %SNMP::Info::PowerEthernet::FUNCS,
+    %SNMP::Info::LLDP::FUNCS,
 );
 
 %MUNGE = (
@@ -73,6 +77,7 @@ $VERSION = '2.06';
     %SNMP::Info::Bridge::MUNGE,
     %SNMP::Info::Entity::MUNGE,
     %SNMP::Info::PowerEthernet::MUNGE,
+    %SNMP::Info::LLDP::MUNGE,
 );
 
 # Method OverRides
@@ -123,30 +128,16 @@ sub serial {
     # precedence
     #   serial2,chassis parse,serial1
     return $serial2 if ( defined $serial2 and $serial2 !~ /^\s*$/ );
-    return $1
-        if ( defined $chassis and $chassis =~ /serial#?:\s*([a-z0-9]+)/i );
+
+    if ( defined $chassis and $chassis =~ /serial#?:\s*([a-z0-9]+)/i ) {
+        return $1;
+    }
+
     return $serial1 if ( defined $serial1 and $serial1 !~ /^\s*$/ );
 
     return;
 }
 
-sub i_ignore {
-    my $l2      = shift;
-    my $partial = shift;
-
-    my $i_type = $l2->i_type($partial) || {};
-
-    my %i_ignore = ();
-
-    foreach my $if ( keys %$i_type ) {
-        my $type = $i_type->{$if};
-        $i_ignore{$if}++
-            if $type =~ /(loopback|other|cpu)/i;
-    }
-
-    return \%i_ignore;
-}
-
 sub interfaces {
     my $l2      = shift;
     my $partial = shift;
@@ -155,10 +146,18 @@ sub interfaces {
     my $i_descr    = $l2->i_description($partial) || {};
 
     # Replace the Index with the ifDescr field.
+    # Check for duplicates in ifDescr, if so uniquely identify by adding
+    # ifIndex to repeated values
+    my %seen;
     foreach my $iid ( keys %$i_descr ) {
         my $port = $i_descr->{$iid};
         next unless defined $port;
-        $interfaces->{$iid} = $port;
+        if ( $seen{$port}++ ) {
+            $interfaces->{$iid} = sprintf( "%s (%d)", $port, $iid );
+        }
+        else {
+            $interfaces->{$iid} = $port;
+        }
     }
     return $interfaces;
 }
@@ -224,6 +223,8 @@ after determining a more specific class using the method above.
 
 =item SNMP::Info::Entity
 
+=item SNMP::Info::LLDP
+
 =back
 
 =head2 Required MIBs
@@ -277,6 +278,10 @@ See documentation in L<SNMP::Info::Bridge/"GLOBALS"> for details.
 
 See documentation in L<SNMP::Info::Entity/"GLOBALS"> for details.
 
+=head2 Globals imported from SNMP::Info::LLDP
+
+See documentation in L<SNMP::Info::LLDP/"GLOBALS"> for details.
+
 =head1 TABLE METHODS
 
 These are methods that return tables of information in the form of a reference
@@ -293,12 +298,6 @@ name.
 
 Defaults to C<ifDescr> but checks and overrides with C<ifName>
 
-=item $l2->i_ignore()
-
-Returns reference to hash.  Increments value of IID if port is to be ignored.
-
-Ignores ports with C<ifType> of loopback, propvirtual, other, and cpu
-
 =back
 
 =head2 Table Methods imported from SNMP::Info
@@ -313,4 +312,8 @@ See documentation in L<SNMP::Info::Bridge/"TABLE METHODS"> for details.
 
 See documentation in L<SNMP::Info::Entity/"TABLE METHODS"> for details.
 
+=head2 Table Methods imported from SNMP::Info::LLDP
+
+See documentation in L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
+
 =cut
